@@ -4,6 +4,6 @@
 
 echo "<repo>/<component>:<tag> : $1"
 
-git config --global url."https://$GITHUB_TOKEN@github.com/stolostron".insteadOf "https://github.com/stolostron"
+git config --global url."https://$GITHUB_TOKEN@github.com/open-cluster-management".insteadOf "https://github.com/open-cluster-management"
 
 go test ./...
\ No newline at end of file
